@@ -1,3 +1,3 @@
 .onAttach <- function(libname = find.package("furniture"), pkgname = "furniture") {
-  packageStartupMessage("furniture 1.5.4: learn more at tysonstanley.github.io")
+  packageStartupMessage("furniture 1.6.0: learn more at tysonbarrett.com")
 }
\ No newline at end of file
